**************************************************
****************  CRUCIALS PATHS  ****************
**************************************************
global stub "Your paths"
global datapath "$stub\data"
global out "$stub\out"
global gvc "$stub\gvc"
cd $out

global a= c(current_time)

*************************************
*********LevPet estimation by WIOD sector**
*************************************
* These assumes the small.dta contains the Amadeus data from the NMS with the WIOD sector identifiers
use "$datapath\small.dta", clear

//crucial loop variables
levelsof country, local(countries)
levelsof wiodn, local(sectors)
//validity check
di $country
di $wiodn

//now we generate the most important variable in this analysis
gen ltfp=. //(6167926 missing values generated)

* This estimates Levpet by sector and saves each sector to a separate file 
foreach cou in `countries' {
	foreach sec in `sectors' {
			display "Sector"
			display "`sec'"
			display "Country"
			display "`cou'"
			capture drop temp	
		preserve
			display "dropping variables"
			keep if wiodn==`sec' & country==`cou'
			display "estimating"
			capture noisily levpet log_va_real if wiodn==`sec' & country==`cou' , free(log_l) proxy(log_m_real) capital(log_k_real) reps(2) //only 2 repetitions?!?!?! this might impact the results... <<valueadded>> option would indicate that the dependent variable represents value added, but this is the default
			display "predicting"
			capture predict temp, omega
			display "replacing"
			capture replace ltfp=temp if wiodn==`sec' & country==`cou'
			keep firm_id year wiodn country ltfp
			save "$datapath\levpet\levpet_`sec'_`cou'.dta", replace //which gives 770 items altogether
		restore
	}
}

* Combining the sectors
preserve
	drop _all
	foreach cou in `countries' {
		foreach sec in `sectors' {
			append using "$datapath\levpet\levpet_`sec'_`cou'.dta"
		}
	}
	sort firm_id year
	save "$datapath\levpet\levpet.dta", replace
restore

drop ltfp

* merging the created TFP data by firm and year with the remaining Amadeus data

merge 1:1 firm_id year using "$datapath\levpet\levpet.dta" 
drop _merge
capture noisily drop log_ltfp
gen log_ltfp = log(ltfp)
save "$datapath\small_with_levpet_log_ltfp", replace


******************************************************
******************************************************
**************  OUTLIERS in log_ltfp *****************
******************************************************
******************************************************
foreach var in log_ltfp {
	bysort country wiod : egen `var'_99 = pctile(`var'), p(99) //(275808 missing values generated)
	bysort country wiod : egen `var'_01 = pctile(`var'), p(01) //(275808 missing values generated)
	drop if `var' > `var'_99 //(60799 observations deleted)
	drop if `var' < `var'_01 //(58601 observations deleted)
	drop `var'_01 `var'_99
}

